@@ -1,38 +1,9 @@
 from ape import plugins
 
+from .config import EtherscanConfig
 from .explorer import Etherscan
 from .query import EtherscanQueryEngine
-
-NETWORKS = {
-    "ethereum": [
-        "mainnet",
-        "goerli",
-    ],
-    "arbitrum": [
-        "mainnet",
-        "goerli",
-    ],
-    "fantom": [
-        "opera",
-        "testnet",
-    ],
-    "optimism": [
-        "mainnet",
-        "goerli",
-    ],
-    "polygon": [
-        "mainnet",
-        "mumbai",
-    ],
-    "avalanche": [
-        "mainnet",
-        "fuji",
-    ],
-    "bsc": [
-        "mainnet",
-        "testnet",
-    ],
-}
+from .utils import NETWORKS
 
 
 @plugins.register(plugins.ExplorerPlugin)
@@ -46,3 +17,8 @@ def explorers():
 @plugins.register(plugins.QueryPlugin)
 def query_engines():
     yield EtherscanQueryEngine
+
+
+@plugins.register(plugins.Config)
+def config_class():
+    return EtherscanConfig
