@@ -6,6 +6,7 @@ from ape.exceptions import QueryEngineError
 from ape.utils import singledispatchmethod
 
 from ape_etherscan.client import ClientFactory
+from ape_etherscan.utils import NETWORKS
 
 
 class EtherscanQueryEngine(QueryAPI):
@@ -20,10 +21,25 @@ class EtherscanQueryEngine(QueryAPI):
     def estimate_query(self, query: QueryType) -> Optional[int]:  # type: ignore[override]
         return None
 
+    @property
+    def rate_limit(self) -> int:
+        config = self.config_manager.get_config("etherscan")
+        return getattr(config, self.network_manager.ecosystem.name.lower()).rate_limit
+
     @estimate_query.register
-    def estimate_account_transaction_query(self, query: AccountTransactionQuery) -> int:
-        # About 15 ms per page of 100 transactions
-        return 1500 * (1 + query.stop_nonce - query.start_nonce) // 100
+    def estimate_account_transaction_query(self, query: AccountTransactionQuery) -> Optional[int]:
+        if self.network_manager.active_provider:
+            # Ignore unsupported networks.
+            ecosystem = self.network_manager.provider.network.ecosystem.name
+            network = self.network_manager.provider.network.name
+            if network not in NETWORKS.get(ecosystem, {}):
+                return None
+
+        # About 15 ms per page of 100 transactions, with rate limit applied
+        if query.stop_nonce - query.stop_nonce <= 100:
+            return 15
+
+        return (10000 // self.rate_limit) * (1 + query.stop_nonce - query.start_nonce) // 100
 
     @singledispatchmethod
     def perform_query(self, query: QueryType) -> Iterator:  # type: ignore[override]
